==> kate-16.08.3.tar.xz: kate-16.08.3/addons/replicode/replicodeplugin.h <==
/* This file is part of the KDE project
   Copyright (C) 2014 Martin Sandsmark <martin.sandsmark@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef REPLICODEPLUGIN_H
#define REPLICODEPLUGIN_H

#include <KTextEditor/Plugin>
#include <KTextEditor/ConfigPage>
#include "replicodeview.h"

class ReplicodePlugin : public KTextEditor::Plugin
{
    Q_OBJECT

  public:
    // Constructor
    explicit ReplicodePlugin(QObject *parent = 0, const QList<QVariant> &args = QList<QVariant>());
    // Destructor
    virtual ~ReplicodePlugin();

    QObject *createView(KTextEditor::MainWindow *mainWindow) {
        return new ReplicodeView(this, mainWindow);
    }

    // Config interface
    int configPages () const { return 1; }
    KTextEditor::ConfigPage *configPage (int number = 0, QWidget *parent = 0);
};

#endif

==> kate-17.08.2.tar.xz: kate-17.08.2/addons/replicode/replicodeplugin.h <==
/* This file is part of the KDE project
   Copyright (C) 2014 Martin Sandsmark <martin.sandsmark@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef REPLICODEPLUGIN_H
#define REPLICODEPLUGIN_H

#include <KTextEditor/Plugin>
#include <KTextEditor/ConfigPage>
#include "replicodeview.h"

class ReplicodePlugin : public KTextEditor::Plugin
{
    Q_OBJECT

  public:
    // Constructor
    explicit ReplicodePlugin(QObject *parent = 0, const QList<QVariant> &args = QList<QVariant>());
    // Destructor
    virtual ~ReplicodePlugin();

    QObject *createView(KTextEditor::MainWindow *mainWindow) Q_DECL_OVERRIDE {
        return new ReplicodeView(this, mainWindow);
    }

    // Config interface
    int configPages () const Q_DECL_OVERRIDE { return 1; }
    KTextEditor::ConfigPage *configPage (int number = 0, QWidget *parent = 0) Q_DECL_OVERRIDE;
};

#endif
